aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorWei-Ning Huang <w@dexon.org>2018-11-21 16:33:15 +0800
committerJimmy Hu <jimmy.hu@dexon.org>2019-04-13 20:54:33 +0800
commit555c842d6970d8844b0d2a9055b279096e7dbf83 (patch)
tree4c2612d9880df56ca870f1e28356608e2ad5ef5c
parent6d1f61b651503210f9125903a51a18d1fba9708d (diff)
downloaddexon-solidity-555c842d6970d8844b0d2a9055b279096e7dbf83.tar.gz
dexon-solidity-555c842d6970d8844b0d2a9055b279096e7dbf83.tar.zst
dexon-solidity-555c842d6970d8844b0d2a9055b279096e7dbf83.zip
Update CI settings
-rw-r--r--.travis.yml4
-rw-r--r--scripts/bytecodecompare/deploy_key.encbin1680 -> 1680 bytes
-rwxr-xr-xscripts/bytecodecompare/storebytecode.sh12
-rwxr-xr-xscripts/docker_build.sh7
-rwxr-xr-xscripts/docker_deploy.sh2
-rw-r--r--scripts/travis-emscripten/deploy_key.encbin1680 -> 1680 bytes
-rwxr-xr-xscripts/travis-emscripten/publish_binary.sh6
7 files changed, 15 insertions, 16 deletions
diff --git a/.travis.yml b/.travis.yml
index 6d3d70e0..76847aec 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -37,7 +37,7 @@ branches:
env:
global:
- - ENCRYPTION_LABEL="6d4541b72666"
+ - ENCRYPTION_LABEL="671c80db"
- SOLC_BUILD_TYPE=RelWithDebInfo
- SOLC_EMSCRIPTEN=Off
- SOLC_INSTALL_DEPS_TRAVIS=On
@@ -240,7 +240,7 @@ deploy:
# This runs for each tag that is created and adds the corresponding files.
- provider: releases
api_key:
- secure: PWH37xVBCF0XiSjl+eH7XIdkrfxZXjzvqF4PiBOnD3VnFz+odrdnIwBmCeBYTHTWF8efpp8fmzWJk2UVq1JcpyZiC+SVxO8dx91W2ia1a+wKrEQuDgkUrZBkl5IQNCv0QS81DDQhliyZEaYh8wHO/7RReyMpGpw2U2u85WkFiZ+LdlHEZPfzUeh9lxQ9n8qwFL8Rja+Q05d4cQ8zaVEtofJJT4T6DUWhc3TzuxDYxOmjwg37rC9CkGSLn6VadSh8b3j5R0SZupFsAEvBL/imBLP9r9ewoo7o4p6By3jwiIgH9yNg7LM618xbffcNaYF/KtLBi9uPHfqF7hRD4PlECz+D0PR78nQItOX5HKm1QMg5kCnghRVCA0IVjpV5fiYQnMLM7dCRv34I5b3zLpa69wQ/GLYB2FViqNUfvPeiZTEeIJ2OmATlFx8AH2JoqpY1XJknWb35+vMfa8LSiJJW++SLWeV+ncC92hrvyZ1cy3trepRRZIfyYepxHifnfdWMkddQUJk5b2WS5Fy/TJLZNPeombnpvRhUC38dsYItarKeXTc6k4oADCEDZ2rgGIcEiqRxXV11Y5xHJekLDWzUs+YJNcCuL4pnAP//LOnbnH2w9rLpwhQYSl0anCd097NivAXQJXO2JI/byIYz1kiCVQWnW6EM8+72mLOklf/Qr8k=
+ secure: cCQMq0Q3aLQshSqBwfZ6itDPq7FZhjGt4BwXKnABSpva9CqTDQTyYWilpFKuSyKlT+rHc8W6ZiZ30rMXM/LPMx/Ij44ameIFvhJaCEM3xQOrAnb6oz3O3gy/mfLaKO7PJY6pteVvxDkKT08nyL35kzr9MsmUgXMz2bcJFED3yKS/QwpTev0H8PSPEqZBXqLleOou0QKu+djLh0UKCXI/u8RfntrTdvkupX1eoweiAscQBUZnokyOl35j6JYuKYxkGFP3OQpx6QeavShPY6xhOiq5rCLNEQRv8D8w982ZxxzfyfZN17qyDublYBkaih5KxMlkUJ0OGlM96D7EU7/qYwwnlPWmH2g/RfHt2ccwb9+eBiEd341d9Nz8y0eHA0gmIsU5ilA1EFrUz/pN9u6matrgmFRgukvU0ygJY9T3Cm2tl8iHW2GfY5UW4aa5HA2eOZQC6G2rz3BsMBnYAdLIF5LDJeSoAPL+Vm1equdTJk9KsZJTqMFGJH5JigYlj00+3waenCEDwl+Lb6vbZeXQl1nzZi82bztRPOySPSSCXoMQTLrQxMwqks/5tr7jY29Ortq3oziNqhKO77Yp7EkTOkWg745K3AK/Zb1pQwpElbnNj73OKhkqGJc3x7ZwvR3V2Y3BD1Iph/qQFfY8rvbzdhDnXGXk6e7oIYjcvDQ9ijA=
overwrite: true
file_glob: true
diff --git a/scripts/bytecodecompare/deploy_key.enc b/scripts/bytecodecompare/deploy_key.enc
index acab2a27..6eddd601 100644
--- a/scripts/bytecodecompare/deploy_key.enc
+++ b/scripts/bytecodecompare/deploy_key.enc
Binary files differ
diff --git a/scripts/docker_build.sh b/scripts/docker_build.sh
index 9eedec34..7400bd4c 100755
--- a/scripts/docker_build.sh
+++ b/scripts/docker_build.sh
@@ -2,11 +2,10 @@
set -e
-# Scratch image
-docker build -t ethereum/solc:build -f scripts/Dockerfile .
-tmp_container=$(docker create ethereum/solc:build sh)
+docker build -t dexonfoundation/dsolc:build -f scripts/Dockerfile .
+tmp_container=$(docker create dexonfoundation/dsolc:build sh)
mkdir -p upload
docker cp ${tmp_container}:/usr/bin/solc upload/solc-static-linux
# Alpine image
-docker build -t ethereum/solc:build-alpine -f scripts/Dockerfile_alpine .
+docker build -t dexonfoundation/dsolc:build-alpine -f scripts/Dockerfile_alpine .
diff --git a/scripts/docker_deploy.sh b/scripts/docker_deploy.sh
index 36e918cf..828b7dd9 100755
--- a/scripts/docker_deploy.sh
+++ b/scripts/docker_deploy.sh
@@ -2,7 +2,7 @@
set -e
-image="ethereum/solc"
+image="dexonfoundation/dsolc"
tag_and_push()
{
diff --git a/scripts/travis-emscripten/deploy_key.enc b/scripts/travis-emscripten/deploy_key.enc
index e6e9e0e6..6eddd601 100644
--- a/scripts/travis-emscripten/deploy_key.enc
+++ b/scripts/travis-emscripten/deploy_key.enc
Binary files differ
diff --git a/scripts/travis-emscripten/publish_binary.sh b/scripts/travis-emscripten/publish_binary.sh
index dd23330b..a5f49af6 100755
--- a/scripts/travis-emscripten/publish_binary.sh
+++ b/scripts/travis-emscripten/publish_binary.sh
@@ -28,7 +28,7 @@
# (c) 2016 solidity contributors.
#------------------------------------------------------------------------------
-set -e
+set -x
VER=$(cat CMakeLists.txt | grep 'set(PROJECT_VERSION' | sed -e 's/.*set(PROJECT_VERSION "\(.*\)".*/\1/')
test -n "$VER"
@@ -50,8 +50,8 @@ ssh-add deploy_key
git clone --depth 2 git@github.com:dexon-foundation/dsolc-bin.git
cd dsolc-bin
-git config user.name "Jimmy Hu"
-git config user.email "jimmy.hu@dexon.org"
+git config user.name "Travis CI"
+git config user.email "dev@dexon.org"
git checkout -B gh-pages origin/gh-pages
git clean -f -d -x
diff --git a/scripts/bytecodecompare/storebytecode.sh b/scripts/bytecodecompare/storebytecode.sh
index 4208d67f..3bc5d666 100755
--- a/scripts/bytecodecompare/storebytecode.sh
+++ b/scripts/bytecodecompare/storebytecode.sh
@@ -3,8 +3,8 @@
#------------------------------------------------------------------------------
# Script used for cross-platform comparison as part of the travis automation.
# Splits all test source code into multiple files, generates bytecode and
# uploads the bytecode into github.com/ethereum/solidity-test-bytecode where
# another travis job is triggered to do the actual comparison.
#
# ------------------------------------------------------------------------------
# This file is part of solidity.
@@ -98,15 +98,15 @@ EOF
if [ "$TRAVIS_SECURE_ENV_VARS" = "true" ]
then
- openssl aes-256-cbc -K $encrypted_60701c962b9c_key -iv $encrypted_60701c962b9c_iv -in "$REPO_ROOT"/scripts/bytecodecompare/deploy_key.enc -out deploy_key -d
+ openssl aes-256-cbc -K $encrypted_671c80db_key -iv $encrypted_671c80db_iv -in "$REPO_ROOT"/scripts/bytecodecompare/deploy_key.enc -out deploy_key -d
chmod 600 deploy_key
eval `ssh-agent -s`
ssh-add deploy_key
- git clone --depth 2 git@github.com:ethereum/solidity-test-bytecode.git
+ git clone --depth 2 git@github.com:dexon-foundation/solidity-test-bytecode.git
cd solidity-test-bytecode
- git config user.name "travis"
- git config user.email "chris@ethereum.org"
+ git config user.name "Travis CI"
+ git config user.email "dev@dexon.org"
git clean -f -d -x
DIRNAME=$(cd "$REPO_ROOT" && git show -s --format="%cd-%H" --date=short)
@@ -3,8 +3,8 @@
# Script used for cross-platform comparison as part of the travis automation.
# Splits all test source code into multiple files, generates bytecode and
-# uploads the bytecode into github.com/ethereum/solidity-test-bytecode where
-# another travis job is triggered to do the actual comparison.
+# uploads the bytecode into github.com/dexon-foundation/solidity-test-bytecode
+# where another travis job is triggered to do the actual comparison.
#
# ------------------------------------------------------------------------------